@@ -225,14 +225,16 @@ sub _build_id ($self) {
     elsif ( -f "$self->{share_dir}/dist-id.yaml" ) {
         $id = P->cfg->read("$self->{share_dir}/dist-id.yaml");
     }
+    else {
+        $id->{release_distance} = '?';
+    }
 
     # convert date to UTC
     $id->{date} = P->date->from_string( $id->{date} )->at_utc->to_string if defined $id->{date};
 
-    $id->{release} //= 'v0.0.0';
+    $id->{release} //= $self->version;
 
     $id->{release_id} = $id->{release};
-
     $id->{release_id} .= "+$id->{release_distance}" if $id->{release_distance};
 
     return $id;
@@ -284,13 +286,19 @@ sub clear ($self) {
 }
 
 sub version_string ($self) {
+    my $id = $self->id;
+
+    if ( !$id->{node} ) {
+        return join $SPACE, $self->name, $id->{release_id};
+    }
+
     my $is_commited = $self->is_commited;
 
     $is_commited //= 1;
 
-    my @tags = $self->id->{tags} ? $self->id->{tags}->@* : ();
+    my @tags = $id->{tags} ? $id->{tags}->@* : ();
 
-    return join $SPACE, $self->name, $self->id->{release_id}, join( $SPACE, grep {$_} $self->id->{branch}, $self->id->{bookmark}, sort @tags ), $self->id->{node} . ( $is_commited ? $EMPTY : q[+] ), $self->id->{date};
+    return join $SPACE, $self->name, $id->{release_id}, join( $SPACE, grep {$_} $id->{branch}, $id->{bookmark}, sort @tags ), $id->{node} . ( $is_commited ? $EMPTY : q[+] ), $id->{date};
 }
 
 sub _build_docker ($self) {
