@@ -180,7 +180,7 @@ sub decode_data ( $type, @ ) {
         if ( bytes::length( $data_ref->$* ) - $token_len == hex $2 ) {
             $args{has_token} = 1;
 
-            substr $data_ref->$*, -$token_len, $token_len, q[];
+            substr $data_ref->$*, -$token_len, $token_len, $EMPTY;
 
             ( $args{compress}, $args{cipher}, $args{secret_index}, $args{encode}, $type ) = split //sm, sprintf '%05s', hex $1;
 
@@ -280,7 +280,7 @@ sub to_perl ( $data, %args ) {
 
     local $Data::Dumper::Indent     = 0;
     local $Data::Dumper::Purity     = 1;
-    local $Data::Dumper::Pad        = q[];
+    local $Data::Dumper::Pad        = $EMPTY;
     local $Data::Dumper::Terse      = 1;
     local $Data::Dumper::Deepcopy   = 0;
     local $Data::Dumper::Quotekeys  = 0;
@@ -301,7 +301,15 @@ sub to_perl ( $data, %args ) {
         no warnings qw[redefine];
 
         local *Data::Dumper::qquote = sub {
-            return q["] . encode_utf8( escape_scalar $_[0] ) . q["];
+            if ( $_[0] eq $EMPTY ) {
+                return q[''];
+            }
+            elsif ( $_[0] =~ /[^[:alnum:]_]/sm ) {
+                return 'qq[' . encode_utf8( escape_scalar $_[0] ) . ']';
+            }
+            else {
+                return "'$_[0]'";
+            }
         };
 
         $res = \Data::Dumper->Dump( [$data] );
@@ -539,7 +547,7 @@ sub to_ini ( $data, @ ) {
 sub from_ini ( $data, @ ) {
     my $cfg = {};
 
-    my @lines = grep { $_ ne q[] } map { trim $_} split /\n/sm, decode_utf8 is_plain_scalarref $data ? $data->$* : $data;
+    my @lines = grep { $_ ne $EMPTY } map { trim $_} split /\n/sm, decode_utf8 is_plain_scalarref $data ? $data->$* : $data;
 
     my $path = $cfg;
 
@@ -565,7 +573,7 @@ sub from_ini ( $data, @ ) {
                 if ( defined $val ) {
                     trim $val;
 
-                    $val = undef if $val eq q[];
+                    $val = undef if $val eq $EMPTY;
                 }
 
                 $path->{ trim $key} = $val;
@@ -616,9 +624,9 @@ sub to_xor ( $buf, $mask ) {
         $mlen = length $mask;
     }
 
-    my $tmp_buf = my $out = q[];
+    my $tmp_buf = my $out = $EMPTY;
 
-    $out .= $tmp_buf ^ $mask while length( $tmp_buf = substr $buf, 0, $mlen, q[] ) == $mlen;
+    $out .= $tmp_buf ^ $mask while length( $tmp_buf = substr $buf, 0, $mlen, $EMPTY ) == $mlen;
 
     $out .= $tmp_buf ^ substr $mask, 0, length $tmp_buf;
 
@@ -954,7 +962,7 @@ sub to_uri_query : prototype($) ($data) {
 
     if ( is_plain_arrayref $data ) {
         for ( my $i = 0; $i <= $data->$#*; $i += 2 ) {
-            push @res, join q[=], defined $data->[$i] ? to_uri_component $data->[$i] : q[], defined $data->[ $i + 1 ] ? to_uri_component $data->[ $i + 1 ] : ();
+            push @res, join q[=], defined $data->[$i] ? to_uri_component $data->[$i] : $EMPTY, defined $data->[ $i + 1 ] ? to_uri_component $data->[ $i + 1 ] : ();
         }
     }
     elsif ( is_plain_hashref $data) {
@@ -990,9 +998,9 @@ sub from_uri_query : prototype($) ($uri) {
         my $val;
 
         if ( ( my $idx = index $key, q[=] ) != -1 ) {
-            $val = substr $key, $idx, length $key, q[];
+            $val = substr $key, $idx, length $key, $EMPTY;
 
-            substr $val, 0, 1, q[];
+            substr $val, 0, 1, $EMPTY;
 
             $val = from_uri $val;
         }
@@ -1014,9 +1022,9 @@ sub from_uri_query_utf8 : prototype($) ($uri) {
         my $val;
 
         if ( ( my $idx = index $key, q[=] ) != -1 ) {
-            $val = substr $key, $idx, length $key, q[];
+            $val = substr $key, $idx, length $key, $EMPTY;
 
-            substr $val, 0, 1, q[];
+            substr $val, 0, 1, $EMPTY;
 
             $val = from_uri_utf8 $val;
         }
@@ -1041,10 +1049,10 @@ sub from_uri_query_utf8 : prototype($) ($uri) {
 ## |      | 159                  | * Subroutine "decode_data" with high complexity score (27)                                                     |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
 ## |    2 |                      | ControlStructures::ProhibitPostfixControls                                                                     |
-## |      | 360, 413             | * Postfix control "for" used                                                                                   |
-## |      | 621                  | * Postfix control "while" used                                                                                 |
+## |      | 368, 421             | * Postfix control "for" used                                                                                   |
+## |      | 629                  | * Postfix control "while" used                                                                                 |
 ## |------+----------------------+----------------------------------------------------------------------------------------------------------------|
-## |    2 | 956                  | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
+## |    2 | 964                  | ControlStructures::ProhibitCStyleForLoops - C-style "for" loop used                                            |
 ## +------+----------------------+----------------------------------------------------------------------------------------------------------------+
 ##
 ## -----SOURCE FILTER LOG END-----
